@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: pkgInterface.h,v 1.25 2001/01/14 16:44:21 toivo Exp $ 
+//      $Id: pkgInterface.h,v 1.29 2001/09/26 16:33:31 mlaurent Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -8,7 +8,7 @@
 #define PKG_IFACE_H
 
 #include "../config.h"
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 #include <qstringlist.h>
 
@@ -48,7 +48,7 @@ class pkgInterface: public QObject
   Q_OBJECT
  
 public:
-  pkgInterface(QString remote);
+  pkgInterface();
   virtual ~pkgInterface();
   
   virtual bool isType(char *buf, const QString &fname) =  0;
@@ -71,16 +71,16 @@ public:
   virtual QStringList verify(packageInfo *p, const QStringList &files);
   // check the installed files in a package
 
-  virtual QString FindFile(const QString &name) = 0;
+  virtual QStringList FindFile(const QString &name) = 0;
   // search for packages containg a file
 
   virtual bool parseName(QString name, QString *n, QString *v) = 0;
   // breakup file name into package name and version
 
-  virtual void listPackages(QList<packageInfo> *pki);
+  virtual void listPackages(QPtrList<packageInfo> *pki);
   // scan various locations for list of packages
 
-  virtual void listInstalledPackages(QList<packageInfo> *pki) = 0;
+  virtual void listInstalledPackages(QPtrList<packageInfo> *pki) = 0;
   // produce list of currently installed packages
 
   virtual QStringList  listInstalls(QStringList packs, bool install);
@@ -92,7 +92,7 @@ public:
   QString getDir(cacheObj *cp);
   // list directory local or remote
 
-  void listDir(QList<packageInfo> *pki, QString fname, QString dir, bool subdirs = FALSE);
+  void listDir(QPtrList<packageInfo> *pki, QString fname, QString dir, bool subdirs = FALSE);
   // list the packages in a directory
 
   packageInfo *collectDir(QString name, QString size, QString dir);
@@ -104,28 +104,22 @@ public:
   virtual QString  provMap(QString p);
   // convert from package depends to package
 
-  void doOptions(int flags, QList<param> &params);
-  QString setOptions(int flags, QList<param> &params);
-
+  QString setOptions(int flags, QPtrList<param> &params);
   // convert un/install flags to text
 
   virtual QString doUninstall(int uninstallFlags, QString packs, bool &test);
   virtual QString doInstall(int installFlags, QString packs, bool &test);
-  virtual QString uninstall(int uninstallFlags, QList<packageInfo> *p,
+  virtual QString uninstall(int uninstallFlags, QPtrList<packageInfo> *p,
 				  bool &test);
   virtual QString uninstall(int uninstallFlags, packageInfo *p,
 				  bool &test);
-  virtual QString install(int installFlags, QList<packageInfo> *p,
+  virtual QString install(int installFlags, QPtrList<packageInfo> *p,
 				  bool &test);
   virtual QString install(int installFlags, packageInfo *p,
 				  bool &test);
 
   ///////////// DATA ///////////////////////
-  //  installationWidget *installation;
-  //  pkginstallDialogMult *installationMult;
   pkgOptions *uninstallation, *installation;;
-  //  pkguninstallDialogMult *uninstallationMult;
-  // install and uninstall widgets for this package type
 
   QString icon;
   // name icon file
@@ -154,15 +148,12 @@ public:
   QString typeID;
   // Parameters for reading packages from directories
 
-  QList<param> paramsInst;
-  QList<param> paramsUninst;
+  QPtrList<param> paramsInst;
+  QPtrList<param> paramsUninst;
 
   bool noFetch;
   // kpackage doesn't fetch this type of package itself
 
-  QString hostName;
-  // Hostname to use for ssh
-
   bool defaultHandle;
 
   procbuf reader;
@@ -171,7 +162,8 @@ public:
 
   QString DELMSG;
 
-  bool isRemote;
+  bool hasRemote;
+  // can access on remote host
 
 public slots:
   virtual void setLocation() = 0;
