@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//     $Id: rpmInstall.cpp,v 1.40 2001/11/05 12:55:39 toivo Exp $
+//     $Id: rpmInstall.cpp,v 1.40.2.1 2002/05/16 15:23:59 toivo Exp $
 #include "../config.h"
 
 #ifdef HAVE_RPM
@@ -623,14 +623,10 @@ QString KprintDepProblems(FILE * f, rpmDependencyConflict conflicts, int numConf
 		    conflicts[i].needsFlags);
     }
     if (conflicts[i].sense == (rpmDependencyConflict::RPMDEP_SENSE_REQUIRES)) { 
-      fprintf(f, i18n(" is needed by %s-%s-%s\n").local8Bit(), conflicts[i].byName, 
-	      conflicts[i].byVersion, conflicts[i].byRelease);
       st += s = i18n(" is needed by %1-%2-%3\n")
 	.arg(conflicts[i].byName)
 	.arg(conflicts[i].byVersion).arg(conflicts[i].byRelease);
     } else {
-      fprintf(f, i18n(" conflicts with %s-%s-%s\n").local8Bit(), conflicts[i].byName, 
-	      conflicts[i].byVersion, conflicts[i].byRelease);
       st += s = i18n(" conflicts with %1-%2-%3\n")
 	.arg(conflicts[i].byName)
 	.arg(conflicts[i].byVersion).arg(conflicts[i].byRelease);
@@ -641,14 +637,10 @@ QString KprintDepProblems(FILE * f, rpmDependencyConflict conflicts, int numConf
       printDepFlags(stderr, st, conflicts->needsVersion, conflicts->needsFlags);
     }
     if (conflicts->sense == (rpmDependencyConflict_s::RPMDEP_SENSE_REQUIRES)) { 
-      fprintf(f, i18n(" is needed by %s-%s-%s\n").local8Bit(), conflicts->byName, 
-	      conflicts->byVersion, conflicts->byRelease);
       st += s = i18n(" is needed by %1-%2-%3\n")
 	.arg(conflicts->byName)
 	.arg(conflicts->byVersion).arg(conflicts->byRelease);
     } else {
-      fprintf(f, i18n(" conflicts with %s-%s-%s\n").local8Bit(), conflicts->byName, 
-	      conflicts->byVersion, conflicts->byRelease);
       st += s = i18n(" conflicts with %1-%2-%3\n")
 	.arg(conflicts->byName)
 	.arg(conflicts->byVersion).arg(conflicts->byRelease);
